<?php
if($this->session->userdata('is_logged_in')===FALSE){
			redirect('login');
}
foreach ($datastatuspenetapan->result() as $row) {

    if($row->status_penetapan_ikrar_talak_id==1){
        $blangko_penetapan_putusan = 'PDT_15_15_210_14';
    }elseif($row->status_penetapan_ikrar_talak_id==2){
        $blangko_penetapan_putusan ='PDT_15_15_210_13';
    }
    elseif($row->status_penetapan_ikrar_talak_id==3){
        $blangko_penetapan_putusan ='PDT_15_15_210_15';
    }
    
}
//if (!empty($dataAktaCerai->num_rows)){


$url = base_url("resources/template/putusan/perdata_agama/".$blangko_penetapan_putusan.".rtf");

$Template = file_get_contents($url);

foreach($dataperkara->result() as $row) {
	$nomorperkara = $row->nomor_perkara;
	$tgl_daftar = $this->templatehelper->convertKeTglIndo($row->tanggal_pendaftaran);
}

$Template = str_replace("#nomor_perkara#",''.$nomorperkara.'',$Template);

foreach($dataAktaCerai->result() as $row) {
    //$status_keadaan = $row->keadaan_istri;
    if($row->keadaan_istri==1){
        $status_keadaan = 'Suci';
    }elseif($row->keadaan_istri==2){
        $status_keadaan ='Haid';
    }
    elseif($row->keadaan_istri==3){
        $status_keadaan ='Sedang Hamil';
    }
    elseif($row->keadaan_istri==4){
        $status_keadaan ='Tidak Diketahui';
    }
    $Template = str_replace("#keadaanistri#",''.$status_keadaan.'',$Template);
}



$namapn = '';
$namakota = '';


foreach ($datapengadilan->result() as $row) {
	$namapn = $this->templatehelper->standradnaming($row->NamaPN);
	$namakota =str_replace("Pengadilan Agama ",'',$namapn);
    $namakota =str_replace("Mahkamah Syar'Iyah ",'',$namapn);
	$zona_waktu = trim($row->ZonaWaktu);
}


$Template = str_replace("Pengadilan Agama ",'',str_replace("#namakota#",ucwords(strtolower($namapn)),$Template));
$Template = str_replace("Mahkamah Syar'iyah ",'',str_replace("#namakota#",ucwords(strtolower($namapn)),$Template));
$Template = str_replace("#nama_pa#",ucwords(strtolower($namapn)),$Template);


$hakimketua = '';
$tanggalpenetapanhakim = '';

$majelis = true;

foreach ($dataPernikahan->result() as $row) {
    $tglnikah = $this->templatehelper->convertKeTglIndo($row->tgl_nikah);
    $tglkutipanAkta = $this->templatehelper->convertKeTglIndo($row->tgl_kutipan_akta_nikah);
    $nobukunikah = $row->no_kutipan_akta_nikah;
    $harinikah = $this->templatehelper->getHari($row->tgl_nikah);
    $namakua = $row->kua_tempat_nikah;
}
$Template = str_replace("#tgl_kutipan_akta_nikah#",''.$tglkutipanAkta.'',$Template);
$Template = str_replace("#nomor_kutipan_akta_nikah#",''.$nobukunikah.'',$Template);
$Template = str_replace("#kua#",''.$namakua.'',$Template);
$Template = str_replace("#hari_nikah#",''.$harinikah.'',$Template);
$Template = str_replace("#tgl_nikah#",''.$tglnikah.'',$Template);


foreach ($datapenetapansidang->result() as $row) {
	$tglsidang = $this->templatehelper->convertKeTglIndo($row->sidang_pertama);
	$tglpenetapansidang = $this->templatehelper->convertKeTglIndo($row->penetapan_hari_sidang);
	$jamsidang = $row->jam_sidang;
	$harisidang = $this->templatehelper->getHari($row->sidang_pertama);
    $namahakim = $row->majelis_hakim_nama;
}

$Template = str_replace("#TGL_SIDANG_PERTAMA#",''.$tglsidang.'',$Template);
$Template = str_replace("#TGL_PHS#",''.$tglpenetapansidang.'',$Template);
$Template = str_replace("#JAM_SIDANG_PERTAMA#",''.substr($jamsidang,0,5).' '.$zona_waktu ,$Template);
$Template = str_replace("#HARI_SIDANG_PERTAMA#",''.$harisidang.'',$Template);
$Template = str_replace("#hakim_anggota#",''.$namahakim.'',$Template);

$i=0;
$temp_pihak='';
$temp_kuasa='';
$pihak_array='';
foreach ($dataPihak1->result() as $row) {
    if($temp_pihak!=$row->id_pihak){
        $temp_pihak=$row->id_pihak;
        if($i>0){
            $pihak_array = str_replace("#ke#",' '.$this->templatehelper->converToAngkaRomawi($i), $pihak_array);
        }
        
        $pihak_array.=$row->nama.', umur '.$row->umur.' tahun, agama '.$row->agama.
                ', pekerjaan '.$row->pekerjaan.', Pendidikan '.$row->pendidikan.
                ', alamat '.$row->alamat;  
                    
        if($row->id_kuasa!=''){
            if($i>0){$pihak_array= str_replace("#DKK#",'', $pihak_array);}
            $pihak_array.=' dalam hal ini memberikan kuasa khusus kepada '.$row->nama_kuasa.
                ' #DKK# advokat/penasehat hukum dari '.$row->nama.
                ' yang berkantor di '.$row->alamat_kuasa.' berdasarkan surat kuasa khusus tanggal '.$this->templatehelper->convertKeTglIndo($row->tgl_kuasa).
                ' sebagai #SEBAGAI_P##ke#;#par#';            
        }else{
            $pihak_array.=' sebagai #SEBAGAI_P##ke#;#par#';    
        }
        $i++;
    }else{
         $pihak_array = str_replace("#DKK#",'dan kawan kawan', $pihak_array);
    }
}
if($i>1){
    $pihak_array = str_replace("#ke#",' '.$this->templatehelper->converToAngkaRomawi($i), $pihak_array);
    $pihak_array = str_replace("#par#",' \\par ', $pihak_array);
}else{
    $pihak_array = str_replace("#ke#",'', $pihak_array);
    $pihak_array = str_replace("#par#",'', $pihak_array);
}
$pihak_array = str_replace("#DKK#",'', $pihak_array);
$Template = str_replace("#loopingpenggugat#",$pihak_array,$Template);

$i=0;
$temp_pihak='';
$temp_kuasa='';
$pihak_array='';
foreach ($dataPihak2->result() as $row) {
    if($temp_pihak!=$row->id_pihak){
        $temp_pihak=$row->id_pihak;
        if($i>0){
            $pihak_array = str_replace("#ke#",' '.$this->templatehelper->converToAngkaRomawi($i), $pihak_array);
        }
        
        $pihak_array.=$row->nama.', umur '.$row->umur.' tahun, agama '.$row->agama.
                ', pekerjaan '.$row->pekerjaan.', Pendidikan '.$row->pendidikan.
                ', alamat '.$row->alamat;  
                    
        if($row->id_kuasa!=''){
            if($i>0){$pihak_array= str_replace("#DKK#",'', $pihak_array);}
            $pihak_array.=' dalam hal ini memberikan kuasa khusus kepada '.$row->nama_kuasa.
                ' #DKK# advokat/penasehat hukum dari '.$row->nama.
                ' yang berkantor di '.$row->alamat_kuasa.' berdasarkan surat kuasa khusus tanggal '.$this->templatehelper->convertKeTglIndo($row->tgl_kuasa).
                ' sebagai #SEBAGAI_T##ke#;#par#';            
        }else{
            $pihak_array.=' sebagai #SEBAGAI_T##ke#;#par#';    
        }
        $i++;
    }else{
         $pihak_array = str_replace("#DKK#",'dan kawan kawan', $pihak_array);
    }
}
if($i>1){
    $pihak_array = str_replace("#ke#",' '.$this->templatehelper->converToAngkaRomawi($i), $pihak_array);
    $pihak_array = str_replace("#par#",' \\par ', $pihak_array);
}else{
    $pihak_array = str_replace("#ke#",'', $pihak_array);
    $pihak_array = str_replace("#par#",'', $pihak_array);
}
$pihak_array = str_replace("#DKK#",'', $pihak_array);
$Template = str_replace("#loopingtergugat#",$pihak_array,$Template);

$idperkara=$this->encrypt->decode(base64_decode($enc));
$idalurperkara = $this->tanggalhelper->getIDAlurPerkara($idperkara);
$jenisPerkaraID=$this->tanggalhelper->getIDJenisPerkara($idperkara);

if ($idalurperkara==15) {
    $Template = str_replace("#GUGATAN_PERMOHONAN#",''."Gugatan".'',$Template);
    if ($jenisPerkaraID==346) {
        $Template = str_replace("#SEBAGAI_P#",''."Pemohon".'',$Template);
        $Template = str_replace("#SEBAGAI_T#",''."Termohon".'',$Template);
    }else{
        $Template = str_replace("#SEBAGAI_P#",''."Penggugat".'',$Template);
        $Template = str_replace("#SEBAGAI_T#",''."Tergugat".'',$Template);
    }
}else{
    $Template = str_replace("#GUGATAN_PERMOHONAN# ",''."Permohonan".'',$Template);   
    $Template = str_replace("#SEBAGAI_P#",''."Pemohon".'',$Template);
    $Template = str_replace("#SEBAGAI_T#",''."Termohon".'',$Template);
}
$Template = str_replace("#NAMA_P#",$dataPihak1->row(0)->nama,$Template);
$Template = str_replace("#NAMA_T#",$dataPihak2->row(0)->nama,$Template);

if ($dataamar->num_rows>0){
    foreach ($dataamar->result() as $row) {
        $amarPutusan =$this->templatehelper->cleanHtmlTagSpecial($row->amar_putusan);
        $tgl_putus = $this->templatehelper->convertKeTglIndo($row->tanggal_putusan);
        }
    $Template = str_replace("#amar_putusan#",''.$amarPutusan.'',$Template);
    $Template = str_replace("#tgl_putus#",''.$tgl_putus.'',$Template);    
}
if ($dataikrartalak->num_rows>0){
    foreach ($dataikrartalak->result() as $row) {
        $namaPP =$this->templatehelper->cleanHtmlTag($row->nama_pp_ikrar);
        //$tgl_putus = $this->templatehelper->convertKeTglIndo($row->tanggal_putusan);
        }
    $Template = str_replace("#nama_pp#",''.$namaPP.'',$Template);
   // $Template = str_replace("#tgl_putus#",''.$tgl_putus.'',$Template);    
}

$temp = explode(' ', ($datapengadilan->row(0)->NamaPN));
$Template = str_replace("#pa/ms#",''. ucwords(strtolower($temp[0].' '. $temp[1])).'',$Template);

$Template = str_replace("#tgl_pendaftaran#", $this->templatehelper->convertKeTglIndo($dataperkara->row(0)->tanggal_pendaftaran) ,$Template);//ditaro bawah supaya sebagainya bisa di replace kembali
$Template = str_replace("#tgl_surat#", $this->templatehelper->convertKeTglIndo($dataperkara->row(0)->tanggal_surat) ,$Template);//ditaro bawah supaya sebagainya bisa di replace kembali

if($datastatuspenetapan!=''){
    if($datastatuspenetapan->num_rows>0){
        foreach ($datastatuspenetapan->result() as $row) {
            $tglikrar = $this->templatehelper->convertKeTglIndo($row->tgl_ikrar_talak);
            $hariikrar = $this->templatehelper->getHari($row->tgl_ikrar_talak);
            $amarikrar = $this->templatehelper->cleanHtmlTagSpecial($row->amar_ikrar_talak);
            $tgl_ikrarselaHijriah = $this->templatehelper->convertToHijriah($row->tgl_ikrar_talak);
            $namahakim = $this->templatehelper->cleanHtmlTagSpecial($row->nama_majelis_ikrar);
        }
        $Template = str_replace("#tgl_ikrar#",$tglikrar,$Template);
        $Template = str_replace("#namahakim#",$namahakim,$Template);
        $Template = str_replace("#hari_ikrar#",$hariikrar,$Template);
        $Template = str_replace("#amar_ikrar#",$amarikrar,$Template);
        $Template = str_replace("#tgl_ikrar_hijriah#",$tgl_ikrarselaHijriah,$Template);
    }
}
$km_lama='';
if ($datapenetapanhakimsebelumnya->num_rows>0) {
    foreach ($datapenetapanhakimsebelumnya->result() as $row) {
        $tgl_penetapan_hakim_sebelumnya=$this->templatehelper->convertKeTglIndo($row->tgl_penetapan_hakim_sebelumnya);
        $km_lama = $row->nama_gelar;
    }
}else{
        $tgl_penetapan_hakim_sebelumnya="...........................";
}
if ($ikrar==0) {
                $hakimketua = '';
                $penetapan = '';
                $tanggalpenetapanhakim = '';
                $majelis = true;
                foreach ($datapenetapanhakim->result() as $row) {
                    if($row->jabatan_hakim_id==1){
                        $penetapan .=$this->templatehelper->standradnaming($row->nama_gelar)." \\tab ".$row->jabatan_hakim_nama.";\\par".PHP_EOL;
                    }elseif($row->jabatan_hakim_id==2){
                        $penetapan .=$this->templatehelper->standradnaming($row->nama_gelar)." \\tab ".$row->jabatan_hakim_nama.";\\par".PHP_EOL;
                    }elseif($row->jabatan_hakim_id==3){
                        $majelis = false;
                        $penetapan .=$this->templatehelper->standradnaming($row->nama_gelar)." \\tab Hakim;\\par".PHP_EOL;
                    }
                    $tanggalpenetapanhakim = $this->templatehelper->convertKeTglIndo($row->tanggal_penetapan);
                }
                if($majelis){
                    $Template = str_replace('#majelis#','Majelis',$Template);
                }else{
                    $Template = str_replace('#majelis#','',$Template);
                }
}else{
            foreach ($penetapanPMHIkrar->result() as $row) {
                $majelis_hakim = $row->majelis_hakim;
                $tgl_putus = $this->templatehelper->convertKeTglIndo($row->tgl_putus);
                $tgl_pmh = $this->templatehelper->convertKeTglIndo($row->tgl_pmh);
            }
            if(empty($tgl_pmh)){
                $tgl_pmh = '........';
                }

            if(empty($tgl_putus)){
            $tgl_putus = '........';
            }

            $nama_km ='..........';
            $nama_anggota1 ='..........';
            $nama_anggota2 ='..........';

            $temp = explode('</br>', $majelis_hakim);

            $i = count($temp);

            switch ($i) {
                case 1:
                    $nama_km =$temp[0];
                    break;
                case 2:
                    $nama_km =$temp[0];
                    $nama_anggota1 =$temp[1];
                    break;
                case 3:
                    $nama_km =$temp[0];
                    $nama_anggota1 =$temp[1];
                    $nama_anggota2 =$temp[2];
                    break;
            }

            $nama_km =$this->templatehelper->standradnaming($nama_km);
            $nama_anggota1 =$this->templatehelper->standradnaming($nama_anggota1);
            $nama_anggota2 =$this->templatehelper->standradnaming($nama_anggota2);

            $Template = str_replace("#nama_pa#",''.$namapn.'',$Template);
            $Template = str_replace("#tgl_pmh#",''.$tgl_pmh.'',$Template);
            $Template = str_replace("#nama_anggota2#",''.$nama_anggota2.'',$Template);
            $Template = str_replace("#nama_anggota1#",''.$nama_anggota1.'',$Template);
            $Template = str_replace("#nama_km#",''.$nama_km.'',$Template);
            $Template = str_replace("#tgl_putus#",''.$tgl_putus.'',$Template);
            $Template = str_replace("#kota_satker#",''.$namakota.'',$Template);
            $Template = str_replace("#tgl_putus#",''.$tgl_putus.'',$Template);
}
if(empty($hakimketua)){
    $hakimketua = '........';
}

if(empty($tanggalpenetapanhakim)){
    $tanggalpenetapanhakim = '........';
}

//$Template = str_replace("#penetapan_hakim#",''.$penetapan.'',$Template);
$Template = str_replace('#tanggalpenetapanhakim#',''.$tanggalpenetapanhakim.'',$Template);
$Template = str_replace("#hakimketua#",''.$hakimketua.'',$Template);
$Template = str_replace('#TGL_PMH#',''.$tgl_penetapan_hakim_sebelumnya.'',$Template);
$counter = 1;
$dkk='';

    
    if($datapenetapanhakim->num_rows>0){
        foreach ($datapenetapanhakim->result() as $row) {

            $keterangan = $row->keterangan;
                if ($keterangan == ''){
                    $keterangan = '..........';
                }

                $Template = str_replace("#alasan#",''.$keterangan.'',$Template);
            if(($row->urutan)==1){
                $ketuaMajelis = $row->nama_gelar;
            }elseif(($row->urutan)==2){
                $hakimAnggota1 = $row->nama_gelar;
            }elseif(($row->urutan)==3){
                $hakimAnggota2 = $row->nama_gelar;
            }
        }
    }


if (!$km_lama==''){
    if ($ketuaMajelis == $km_lama){
        $km_anggota='Ketua Majelis';
    }else{
        $km_anggota='Anggota Majelis';
    }
    $Template = str_replace("#km_anggota#",''.$km_anggota.'',$Template);
}

$Template = str_replace("#NAMA_MAJELIS#",''.$ketuaMajelis.'',$Template);
$Template = str_replace("#NAMA_ANGGOTA1#",''.$hakimAnggota1.'',$Template);
$Template = str_replace("#NAMA_ANGGOTA2#",''.$hakimAnggota2.'',$Template);

header("Content-Type: application/vnd.ms-word");
header("Expires: 0");
header("Cache-Control:  must-revalidate, post-check=0, pre-check=0");
header("Content-disposition: attachment; filename=\""."Penetapan Putusan Ikrar "."$status_keadaan"."-".$nomorperkara.".rtf\"");
echo $Template;
?>